@@ -1,5 +1,5 @@
 #Data Analysis for Multiple Batches
-## library(stats4)        ### nor requrired these three lines.  -YJ
+## library(stats4)        ### nor required these three lines.  -YJ
 ## library(MASS)
 ## library(reshape) 
 #predict req. stats4 package
@@ -81,7 +81,7 @@ cat("*****************************************************************\n")
 cat("*                 Analyzing the data now...                     *\n")
 cat("*****************************************************************\n\n")
 zz <- file(output_to_txt, open="wt")
-sink(zz,split=TRUE)              ### add'split=TRUE" here to see it on screen too. - YJ
+sink(zz,split=TRUE)              ### add 'split=TRUE" here to see it on screen too. - YJ
 stab.version()
 cat("<< --- List of input data --- >>\n\n")
 show(Multipledata)
@@ -158,7 +158,7 @@ cat("--------------------------------------------------------------------------\
 cat("                    <<Summary: linear regression model>>                \n\n")
 W.split<-split(ANCOVAdata, list(ANCOVAdata$batch))
   ba<-0
-     for (i in 1:(length(W.split))){     ### get bactch# here -YJ
+     for (i in 1:(length(W.split))){     ### get batch# here -YJ
      ba[i]<-W.split[[i]][["batch"]][1]
      }
      
@@ -180,7 +180,7 @@ Slope<-coef(lm(assay ~ time, data=ANCOVAdata))[2]       ### 2nd get common 'slop
 
 ### 95%CI,n-2 T value
 ###       
-### prepare to contruct 95%CI & find intersect here! -YJ 
+### prepare to construct 95%CI & find intersect here! -YJ 
 ###      
 cat(" --- Batch#:", ba,"---\n")   ### starting output here
 
@@ -214,7 +214,7 @@ else {
        x<-ANCOVAdata$time            ### here pool all data together because they all share same intercept & slope (for model#1)
        y<-ANCOVAdata$assay
 ###       
-### prepare to contruct 95%CI here -YJ 
+### prepare to construct 95%CI here -YJ 
 ###      
        mylm<-lm(y~x)
        newx<-data.frame(xx=seq(0,84))
@@ -225,12 +225,12 @@ else {
        PY2<-0
        for (i in 1:length(newx$xx)){
              if (total$Lower[i]<Lper){
-                 PY1<-(i-2);break()}}        ### this is one interscet for lower line; use break() to stop finding... --YJ (great!)
+                 PY1<-(i-2);break()}}        ### this is one intersect for lower line; use break() to stop finding... --YJ (great!)
        if (PY1==0||PY1<0) {PY1<-84}          ### means cannot find a solution for lower
 
        for (i in 1:length(newx$xx)){
               if (total$Upper[i]>Uper){
-                 PY2<-(i-2);break() }}      ### this is one interscet for upper line; use break() to stop finding... --YJ (great!)
+                 PY2<-(i-2);break() }}      ### this is one intersect for upper line; use break() to stop finding... --YJ (great!)
        if (PY2==0||PY2<0) {PY2<-84}         ### means cannot find a solution for upper
        PY<-min(PY1,PY2)                     ### pick a minimum PY as shelf-life here if there are two intersects. -YJ
 } 
@@ -283,7 +283,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
 
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      #i<-formatC(PX,format="f",digits=2) 
      #i<-round(PX,3) #same as the above 
      shelflife<-as.integer(PPY)
@@ -352,7 +353,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
 
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife, "months"),collapse=" ")
      x<-ANCOVAdata$time
@@ -392,7 +394,7 @@ else {
         dev.set(which=x11c)             ## back to graphics device
      }
      cat("------------------------------------------------------------------\n\n")
-     cat(" Drug product with upper acceptance limiy of",Uper,"% of label claim\n")
+     cat(" Drug product with upper acceptance limit of",Uper,"% of label claim\n")
      cat(" shelf-life =",shelflife,"(months)                           \n\n")
      cat("******************************************************************\n")
      cat("\n")
@@ -417,7 +419,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
 
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife, "months"),collapse=" ")
      x<-ANCOVAdata$time
@@ -468,7 +471,7 @@ else {
    }
 }
 ### end of two-sided.
-### do Q-Q plot only if there is at leat one solution (shelf-life)
+### do Q-Q plot only if there is at least one solution (shelf-life)
 if (!noSolution) {
     output<-data.frame(ANCOVAdata$batch,ANCOVAdata$time,ANCOVAdata$assay,cal,Res)
     colors<-data.frame(colx=seq(1,100))         ### for when the batch# is not coded as 1, 2, 3, ... - YJ
@@ -495,6 +498,7 @@ if (!noSolution) {
       }
     sink()
     close(zz)
+    readline(" Done. Press any key to continue...")
     dev.off()
        cat("*****************************************************************************\n\n")
        cat("## Please note: The output files (",output_to_txt,") and (",plots_to_pdf,")     \n")
@@ -590,7 +594,7 @@ K.split<-split(Multipledata, list(Multipledata$batch))
 		     PY<-0 
 		     TT<-0
 		     
-  for (j in 1:length(W.split)){     # preccess batch by batch now... not the same with Model# 1. --YJ
+  for (j in 1:length(W.split)){     # precess batch by batch now... not the same with Model# 1. --YJ
           Intercept<-0
           for(x in 1: length(unique(Intable$batch))){
                 if (W.split[[j]][["batch"]][1]==Intable$batch[[x]]){
@@ -656,7 +660,7 @@ K.split<-split(Multipledata, list(Multipledata$batch))
 ###  Pause here..
 ###  show LX, L[j]-->  8 8 
 ### 
-### conclusin: we should use L[j], not LX here. -YJ (great!) see: drug_stability example textbook, p.617.
+### conclusion: we should use L[j], not LX here. -YJ (great!) see: drug_stability example textbook, p.617.
 ###            because it is within a batch, not between the batch.!  Haha~  
 
            ### cat(" show LX, L[j]--> ",LX,L[j],"\n\n")
@@ -793,7 +797,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
      
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife, "months"),collapse=" ")    
      plot(time~assay,data=ANCOVAdata, xlim=c(0,84),ylim=c((Lper-10),(max(assay))), main=main,
@@ -890,7 +895,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
      
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife, "months"),collapse=" ")    
      plot(time~assay,data=ANCOVAdata,xlim=c(0,84),ylim=c((Uper-20),(Uper+20)), main=main,   ### why? because it is upper!!  -YJ
@@ -976,7 +982,8 @@ cat("**************************************************************************\
    noSolution = TRUE
 }
 else {
-     windows(record = TRUE)
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      allSF<-data.frame(ba,PY)
      colnames(allSF)<-c(" batch#", "  shelf-life*")
      show(allSF)
@@ -1061,7 +1068,7 @@ else {
        cat("\n")
  }
 ### end of two-sided.
-### do Q-Q plot only if there is at leat one solution (shelf life)
+### do Q-Q plot only if there is at least one solution (shelf life)
 if (!noSolution) {
     colors<-data.frame(colx=seq(1,100))         ### for when the batch# is not coded as 1, 2, 3, ... - YJ
     qqnorm(QQ$value, las=1, main = "Normal Q-Q Plot of Residuals", lwd=3, col=c(colors$colx), frame.plot=FALSE)  
@@ -1086,6 +1093,7 @@ if (!noSolution) {
      }
    sink()
    close(zz)
+   readline(" Done. Press any key to continue...")
    dev.off()
        cat("*****************************************************************************\n\n")
        cat("## Please note: The output files (",output_to_txt,") and (",plots_to_pdf,")     \n")
@@ -1205,7 +1213,7 @@ cat("\n")
         L[j]<-length(W.split[[j]][["time"]])  
 ### 95%CI,n-2 T value
 ###       
-### prepare to contruct 95%CI here -YJ 
+### prepare to construct 95%CI here -YJ 
 ###
         cat(" --- Batch#:", ba[j],"---\n")    ### starting output here
         if(onesidedlo || onesidedup){
@@ -1318,7 +1326,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
 
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
 ### go to plot of single batch
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife,"months"),collapse=" ")    
@@ -1390,7 +1399,8 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
 
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife, "months"),collapse=" ")    
      plot(time~assay,data=ANCOVAdata,xlim=c(0,84),ylim=c((Uper-30),(Uper+10)), main=main,
@@ -1459,9 +1469,10 @@ else {
      cat(" cannot find a reasonable shelf-life for the\n")
      cat(" batch with presented dataset within 84 months.\n\n")
 
-     windows(record = TRUE )  ### now start preparing to plot...
+     ### windows(record = TRUE )  ### NOT working in linux/unix any more; change to dev.new()
+     dev.new()
 ### go to plot of single batch
-### oultine plot box 
+### outline plot box 
      shelflife<-as.integer(PPY)
      main<-paste(c("estimated shelf-life =",shelflife,"months"),collapse=" ")    
      plot(time~assay,data=ANCOVAdata, xlim=c(0,84),ylim=c((Lper-10),(Uper+10)), main=main,
@@ -1515,7 +1526,7 @@ else {
    }
  }
 ### end of two-sided.
-### do Q-Q plot only if there is at leat one solution (shelf life)
+### do Q-Q plot only if there is at least one solution (shelf life)
 if (!noSolution) {
     colors<-data.frame(colx=seq(1,100))         ### for when the batch# is not coded as 1, 2, 3, ... - YJ
     qqnorm(QQ$value, las=1, main = "Normal Q-Q Plot of Residuals", lwd=3, col=c(QQ$L1),frame.plot=FALSE)
@@ -1540,6 +1551,7 @@ if (!noSolution) {
      }
    sink()
    close(zz)
+   readline(" Done. Press any key to continue...")
    dev.off()
        cat("*****************************************************************************\n\n")
        cat("## Please note: The output files (",output_to_txt,") and (",plots_to_pdf,")     \n")
